<?php
/** Jamaican Creole English (Patois)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Hazard-SJ
 * @author Ukabia
 * @author Yocahuna
 * @author គីមស៊្រុន
 */

$messages = array(
# User preference toggles
'tog-underline' => 'Lingk andalainin',
'tog-justify' => 'Jostifai paragraaf',
'tog-hideminor' => 'Aid maina edit ina riisant chienj',
'tog-hidepatrolled' => 'Aid pachruol edit ina riisant chienj',
'tog-newpageshidepatrolled' => 'Aid pachruol piej frahn nyuu piej lis',
'tog-extendwatchlist' => 'Expan wachlis fi shuo aal chienj, no jos di muos riisant',
'tog-usenewrc' => 'Yuuz enans riisant chienj (rikwaya JavaScript)',
'tog-numberheadings' => 'Aato-nomba edndem',
'tog-showtoolbar' => 'Shuo edit tuulbaar (rikwaya JavaScript)',
'tog-editondblclick' => 'Edit piej pahn dobl klik (rikwaya JavaScript)',
'tog-editsection' => 'Eniebl sekshan editin vaya [edit] lingk',
'tog-editsectiononrightclick' => 'Eniebl sekshan editin bai rait klikin pahn sekshan taikl (rikwaya JavaScript)',
'tog-showtoc' => 'Shuo tiebl a kantent (fi piej wid muo dan 3 edn)',
'tog-rememberpassword' => 'Memba mi lagiin pahn dis brouza (fi a maximom a $1 {{PLURAL:$1|die|die}})',
'tog-watchcreations' => 'Ad piej mi kriet tu mi wachlis',
'tog-watchdefault' => 'Ad piej mi edit tu mi wachlis',
'tog-watchmoves' => 'Ad piej mi muuv tu mi wachlis',
'tog-watchdeletion' => 'Ad piej mi diliit tu mi wachlis',
'tog-previewontop' => 'Shuo priivyuu bifuo edit bax',
'tog-previewonfirst' => 'Shuo priivyuu pahn fos edit',
'tog-nocache' => 'Disiebl brouza piej kiashin',
'tog-enotifwatchlistpages' => 'E-miel mi wen piej pahn mi wachlis chienj',
'tog-enotifusertalkpages' => 'E-miel mi wen mi yuuza taak piej chienj',
'tog-enotifminoredits' => 'E-miel mi alzwel fi maina edit pahn piej',
'tog-enotifrevealaddr' => 'Riviil mi e-miel ajres ina nuotifikieshan e-miel',
'tog-shownumberswatching' => 'Shuo di nomba a wachin yuuza',
'tog-oldsig' => 'Priivyuu a egzisin signicha:',
'tog-fancysig' => 'Chriit signicha az wikitex (widoutn aatamatik lingk)',
'tog-uselivepreview' => 'Yuuz laiv priivyuu (rikwaya JavaScript) (experimental)',
'tog-forceeditsummary' => 'Pramp mi wen entarin blangk edit somari',
'tog-watchlisthideown' => 'Aid mi editdem frahn di wachlis',
'tog-watchlisthidebots' => 'Aid bat editdem frahn di wachlis',
'tog-watchlisthideminor' => 'Aid maina editdem frahn di wachlis',
'tog-watchlisthideliu' => 'Aid editdem bai lag iin yuuza frahn di wachlis',
'tog-watchlisthideanons' => 'Aid editdem bai ananimos yuuza frahn di wachlis',
'tog-watchlisthidepatrolled' => 'Aid pachruol editdem frahn di wachlis',
'tog-ccmeonemails' => 'Sen mi kapi a e-miel mi sen tu ada yuuza',
'tog-diffonly' => 'No shuo piej kantent biluo dif',
'tog-showhiddencats' => 'Shuo aidwe kiatigari',
'tog-norollbackdiff' => '
Lef aaf dif afta pofaamin ruolbak',

'underline-always' => 'Alzwie',
'underline-never' => 'Neba',
'underline-default' => 'Brouza difaalt',

# Font style option in Special:Preferences
'editfont-style' => 'Edit ieria font stail:',
'editfont-default' => 'Brouza difaalt',
'editfont-monospace' => 'Monospies font',
'editfont-sansserif' => 'San-serif font',
'editfont-serif' => 'Serif font',

# Dates
'sunday' => 'Sonde',
'monday' => 'Monde',
'tuesday' => 'Tyuuzde',
'wednesday' => 'Wenzde',
'thursday' => 'Torzde',
'friday' => 'Fraide',
'saturday' => 'Satide',
'sun' => 'Son',
'mon' => 'Mon',
'tue' => 'Tyu',
'wed' => 'Wen',
'thu' => 'Tor',
'fri' => 'Fra',
'sat' => 'Sat',
'january' => 'Janiweri',
'february' => 'Febiweri',
'march' => 'Maach',
'april' => 'Iepril',
'may_long' => 'Mie',
'june' => 'Juun',
'july' => 'Julai',
'august' => 'Aagos',
'september' => 'Septemba',
'october' => 'Aktuoba',
'november' => 'Novemba',
'december' => 'Disemba',
'january-gen' => 'Janiweri',
'february-gen' => 'Febiweri',
'march-gen' => 'Maach',
'april-gen' => 'Iepril',
'may-gen' => 'Mie',
'june-gen' => 'Juun',
'july-gen' => 'Julai',
'august-gen' => 'Aagos',
'september-gen' => 'Septemba',
'october-gen' => 'Aktuoba',
'november-gen' => 'Novemba',
'december-gen' => 'Disemba',
'jan' => 'Jan',
'feb' => 'Feb',
'mar' => 'Maa',
'apr' => 'Iep',
'may' => 'Mie',
'jun' => 'Juu',
'jul' => 'Jul',
'aug' => 'Aag',
'sep' => 'Sep',
'oct' => 'Akt',
'nov' => 'Nov',
'dec' => 'Dis',

# Categories related messages
'pagecategories' => '{{PLURAL:$1|Kiatigari|Kiatigaridem}}',
'category_header' => 'Piejdem ina kiatigari "$1"',
'subcategories' => 'Sobkiatigari',
'category-media-header' => 'Midia ina kiatigari "$1"',
'category-empty' => "''Dis kiatigari korantli no kantien no piej nar midia.''",
'hidden-categories' => '{{PLURAL:$1|Idn kiatigari|Idn kiatigaridem}}',
'hidden-category-category' => 'Aidwe kiatigari',
'category-subcat-count' => '{{PLURAL:$2|Dis kiatigari ab onggl di falarin sobkiatigari.|Dis kiatigari ab di falarin {{PLURAL:$1|sobkiatigari|$1 sobkiatigaridem}}, out a $2 tuotal.}}',
'category-subcat-count-limited' => 'Dis kiatigari ab di falarin {{PLURAL:$1|sobkiatigari|$1 sobkiatigari}}.',
'category-article-count' => '{{PLURAL:$2|Dis kiatigari kantien onggl di falarin piej.|Di falarin {{PLURAL:$1|piej a|$1 piejdem a}} ina dis kiatigari, outa $2 tuotal.}}',
'category-article-count-limited' => 'Di falarin {{PLURAL:$1|piej de|$1 piej de}} ina di korant kiatigari.',
'category-file-count' => '{{PLURAL:$2|Dis kiatigari kantien onggl di falarin file.|Di falarin {{PLURAL:$1|fail de|$1 fail de}} ina dis kiatigari, outa $2 tuotal.}}',
'category-file-count-limited' => 'Di falarin {{PLURAL:$1|fail de|$1 fail de}} ina di korant kiatigari.',
'listingcontinuesabbrev' => 'kant.',
'index-category' => 'Index piej',
'noindex-category' => 'No index piej',

'about' => 'Bout',
'article' => 'Kantent piej',
'newwindow' => '(opn ina nyuu winda)',
'cancel' => 'Kiansl',
'moredotdotdot' => 'Muo...',
'mypage' => 'Fimi Piej',
'mytalk' => 'Mi chat',
'anontalk' => 'Taak fi dis IP ajres',
'navigation' => 'Navigieshan',
'and' => '&#32;ahn',

# Cologne Blue skin
'qbfind' => 'Fain',
'qbbrowse' => 'Brouz',
'qbedit' => 'Edit',
'qbpageoptions' => 'Dis piej',
'qbmyoptions' => 'Mi piejdem',
'qbspecialpages' => 'Peshal piejdem',
'faq' => 'FAK',
'faqpage' => 'Project:FAK',

# Vector skin
'vector-action-addsection' => 'Ad tapik',
'vector-action-delete' => 'Diliit',
'vector-action-move' => 'Muuv',
'vector-action-protect' => 'Protek',
'vector-action-undelete' => 'Andiliit',
'vector-action-unprotect' => 'Neu protektian',
'vector-simplesearch-preference' => 'Eniebl enans saach sojeshan (Vekta skin onli)',
'vector-view-create' => 'Kriet',
'vector-view-edit' => 'Hedit',
'vector-view-history' => 'Vyuu ischri',
'vector-view-view' => 'Riid',
'vector-view-viewsource' => 'Vyuu Suos',
'actions' => 'Akshan',
'namespaces' => 'Niemspies',
'variants' => 'Vieriant',

'errorpagetitle' => 'Era',
'returnto' => 'Ritoern a $1',
'tagline' => 'Frahn {{SITENAME}}',
'help' => 'Elp',
'search' => 'Saach',
'searchbutton' => 'Saach',
'go' => 'Gwaan',
'searcharticle' => 'Gwaan',
'history' => 'Piej ischri',
'history_short' => 'Ischri',
'updatedmarker' => 'opdiet sens mi laas vizit',
'printableversion' => 'Printobl voerjan',
'permalink' => 'Poermanint lingk',
'print' => 'Print',
'view' => 'Riid',
'edit' => 'Edit',
'create' => 'Kriet',
'editthispage' => 'Edit dis piej',
'create-this-page' => 'Kriet dis piej',
'delete' => 'Diliit',
'deletethispage' => 'Diliit dis piej',
'undelete_short' => 'Andiliit {{PLURAL:$1|wan edit|$1 edit}}',
'viewdeleted_short' => 'Riid {{PLURAL:$1|wan diliitid hedit|$1 diliitid hedit dem}}',
'protect' => 'Protek',
'protect_change' => 'chienj',
'protectthispage' => 'Protek dis piej',
'unprotect' => 'Neu protektian',
'unprotectthispage' => 'Neu protektian fi dis piej',
'newpage' => 'Nyuu piej',
'talkpage' => 'Diskos dis piej',
'talkpagelinktext' => 'Chat',
'specialpage' => 'Peshal piej',
'personaltools' => 'Persnal tuuldem',
'postcomment' => 'Nyuu sekshan',
'articlepage' => 'Vyuu kantent piej',
'talk' => 'Diskoshan',
'views' => 'Vyuu',
'toolbox' => 'Tuulbax',
'userpage' => 'Vyuu yuuza piej',
'projectpage' => 'Vyuu prajek piej',
'imagepage' => 'Vyuu fail piej',
'mediawikipage' => 'Vyuu mechiz piej',
'templatepage' => 'Vyuu templit piej',
'viewhelppage' => 'Vyuu elp piej',
'categorypage' => 'Vyuu kiatigari piej',
'viewtalkpage' => 'Vyuu diskoshan',
'otherlanguages' => 'Ina ada langwij',
'redirectedfrom' => '(Riidirek frahn $1)',
'redirectpagesub' => 'Riidirek piej',
'lastmodifiedat' => 'Dis piej laas madifai pahn $1, a $2',
'viewcount' => 'Dis piej akses {{PLURAL:$1|wans|$1 taim}}.',
'protectedpage' => 'Protek piej',
'jumpto' => 'Jomp go a:',
'jumptonavigation' => 'navigieshan',
'jumptosearch' => 'saach',
'view-pool-error' => 'Sari, di soervadem uobaluod a di muoment.
Tomoch yuuza a chrai fi vyuu dis piej.
Begyu wiet likl bifuo yu chrai fi akses dis piej agen.

$1',
'pool-timeout' => 'Taimout a wiet fi di lak',
'pool-queuefull' => 'Puul kyuu fulop',
'pool-errorunknown' => 'Anuon era',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage).
'aboutsite' => 'Habowt {{SITENAME}}',
'aboutpage' => 'Project: អំពី',
'copyright' => 'Kantent avielobl anda $1.',
'copyrightpage' => '{{ns:project}}:Kapirait',
'currentevents' => 'Korant ivent',
'currentevents-url' => 'Project:Korant ivent',
'disclaimers' => 'Diskliema',
'disclaimerpage' => 'Project: Jinaral diskliema',
'edithelp' => 'Editin elp',
'helppage' => 'Help: Kantent',
'mainpage' => 'Mien piej',
'mainpage-description' => 'Mien piej',
'policy-url' => 'Project:Palisi',
'portal' => 'Komiuniti puotal',
'portal-url' => 'Project:Komiuniti puotal',
'privacy' => 'Praivisi palisi',
'privacypage' => 'Project: Praivisi palisi',

'badaccess' => 'Poermishan era',
'badaccess-group0' => 'Yu no lou fi exikyuut di akshan yu rikwes.',
'badaccess-groups' => 'Di akshan yu rikwes limit tu yuuza ina {{PLURAL:$2|di gruup|wan a di gruup}}: $1.',

'versionrequired' => 'Voerjan $1 a MediaWiki rikwaya',
'versionrequiredtext' => 'Voerjan $1 a MediaWiki rikwaya fi yuuz dis piej.
Si [[Special:Version|voerjan piej]].',

'ok' => 'OK',
'retrievedfrom' => 'Richriiv frahn "$1"',
'youhavenewmessages' => 'Yu gat $1 ($2).',
'newmessageslink' => 'nyuu mechiz',
'newmessagesdifflink' => 'laas chienj',
'youhavenewmessagesmulti' => 'Yu gat nyuu mechiz pahn $1',
'editsection' => 'edit',
'editold' => 'edit',
'viewsourceold' => 'vyuu suos',
'editlink' => 'edit',
'viewsourcelink' => 'vyuu suos',
'editsectionhint' => 'Edit sekshan: $1',
'toc' => 'Kantent',
'showtoc' => 'shuo',
'hidetoc' => 'aid',
'collapsible-expand' => 'Hexpand',
'thisisdeleted' => 'Vyuu ar ristuor $1?',
'viewdeleted' => 'Vyuu $1?',
'restorelink' => '{{PLURAL:$1|wan diliitid edit|$1 diliitid edit}}',
'feedlinks' => 'Fiid:',
'feed-invalid' => 'Invalid sobskripshan fiid taip',
'feed-unavailable' => 'Sindikieshan fiid no avielobl',
'site-rss-feed' => '$1 RSS fiid',
'site-atom-feed' => '$1 Atom fiid',
'page-rss-feed' => '"$1" RSS fiid',
'page-atom-feed' => '"$1" Atom fiid',
'red-link-title' => '$1 (piej no egzis)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main' => 'Piej',
'nstab-user' => 'Yuuza piej',
'nstab-media' => 'Midia piej',
'nstab-special' => 'Peshal piej',
'nstab-project' => 'Prajek piej',
'nstab-image' => 'Fail',
'nstab-mediawiki' => 'Mechiz',
'nstab-template' => 'Templit',
'nstab-help' => 'Elp piej',
'nstab-category' => 'Kiatigari',

# Main script and global functions
'nosuchaction' => 'No soch akshan',
'nosuchactiontext' => 'Di akshan spesifai bai di URL invalid.
Yu maita mistaip di URL, ar fala a inkarek lingk.
Dis maita indikiet alzwel wahn bog ina di saafwier yuuz bai {{SITENAME}}.',
'nosuchspecialpage' => 'No soch peshal piej',
'nospecialpagetext' => '<strong>Yu rikwes a invalid peshal piej.</strong>

A lis a valid peshal piej kiahn fain a [[Special:SpecialPages|{{int:specialpages}}]].',

# General errors
'error' => 'Era',
'databaseerror' => 'Dietabies era',
'laggedslavemode' => "'''Waanin:''' Piej maita no kantien riisant opdiet.",
'readonly' => 'Dietabies lak',
'enterlockreason' => 'Enta a riizn fi di lak, inkluudn a estimet a wen di lak wi riliis',
'readonlytext' => 'Di dietabies korantli lak gens nyuu enchri ahn ada madifikieshan, prabli fi ruutiin dietabies mientenans, iwi bak tu naamal afta.

Di adminischrieta uu laki aafa dis explanieshan: $1',
'missing-article' => 'Di dietabies no fain di tex ishuda fain, niem "$1" $2.

Dis yuujal kaaz ef ifala outdiet dif ar ischri lingk to piej wa diliit.

Ef dis a no di kies, a maita fain yu fain bog ina di saafwier.
Begyu ripuot dis tu wahn [[Special:ListUsers/sysop|administrieta]], mek nuot a di URL.',
'missingarticle-rev' => '(rivijan#: $1)',
'missingarticle-diff' => '(Dif: $1, $2)',
'readonly_lag' => 'Di dietabies aatamatikali lak wails di sliev dietabies soervadem kechop tu di maasta',
'internalerror' => 'Intoernal era',
'internalerror_info' => 'Intoernal era: $1',
'fileappenderrorread' => 'Kudn riid "$1" juurin apen.',
'fileappenderror' => 'Kudn apen "$1" tu "$2".',
'filecopyerror' => 'Kudn kapi fail "$1" tu "$2".',
'filerenameerror' => 'Kudn riiniem fail "$1" tu "$2".',
'filedeleteerror' => 'Kudn diliit fail "$1".',
'directorycreateerror' => 'Kudn kriet direkchri "$1".',
'filenotfound' => 'Kudn fain fail "$1".',
'fileexistserror' => 'Aniebl fi rait tu fail "$1": fail egzis',
'unexpected' => 'Anexpektid valyu: "$1"="$2".',
'formerror' => 'Era: kudn sobmit faam',
'badarticleerror' => 'Dis akshan kyaahn pofaam pahn dis piej.',
'cannotdelete' => 'The page or file "$1" could not be deleted.
It may have already been deleted by someone else.

Di piej ar fail "$1" kudn diliit.
Imaita aredi diliit bai smadi els.',
'badtitle' => 'Bad taikl',
'badtitletext' => 'Di piej taikl yu rikwes invalid, emti, ar a inkarek lingk inta-langwij ar inta-wiki taikl. Imaita kantien wan ar muo kiarakta we kyaahn yuuz ina taikl.',
'perfcached' => 'Di falarin dieta kiash ahn maita no op tu diet. A maximum of {{PLURAL:$1|one result is|$1 results are}} available in the cache.',
'perfcachedts' => 'Di falarin dieta kiash, ahn laas opdiet $1. A maximum of {{PLURAL:$4|one result is|$4 results are}} available in the cache.',
'querypage-no-updates' => 'Opdiet fi dis piej korantli disiebl.
Dieta ya no go rifresh fi nou.',
'wrong_wfQuery_params' => 'Inkarek paramita tu wfQuery()<br />
Fongshan: $1<br />
Kwieri: $2',
'viewsource' => 'Vyuu Suos',
'actionthrottled' => 'Akshan chratl',
'actionthrottledtext' => 'Az anti-spam meja, yu limit frahn pofaam dis akshan tomoch taim ina shaat spies a taim, ahn yu exiid di limit.
Begyu chrai agen ina fyuu minit.',
'protectedpagetext' => 'Dis piej protek fi privent editin.',
'viewsourcetext' => 'Yu kiahn vyuu ahn kapi di suos a dis piej:',
'protectedinterface' => 'Dis piej provaid intafies tex fi di saafwier, ahn iprotek fi privent abyuus.',
'editinginterface' => "'''Waanin:''' Yu de edit page we yuuz fi provaid intafies tex fi di saafwier.
Chienj tu dis piej wi afek di apierans a di yuuza intafies fi ada yuuzadem.
Fi chranslieshan, begyu kansida fi yuuz [//translatewiki.net/wiki/Main_Page?setlang=en translatewiki.net], di MediaWiki luokalaizieshan projek.",
'cascadeprotected' => 'Dis piej protek frahn edit, bikaa i\'inkluud ina di falarin {{PLURAL:$1|piej, ush|piejdem, ush}} protek wid di "kiaskiedn" apshan ton aan:
$2',
'namespaceprotected' => "Yu no gat no pomishan fi edit piej ina di '''$1''' niemspies.",
'ns-specialprotected' => 'Peshal piejdem kyaahn edit.',
'titleprotected' => 'Dis taikl protek frahn krieshan bai [[User:$1|$1]].
Di riizn dehn gi a "\'\'$2\'\'".',

# Virus scanner
'virus-badscanner' => "Bad kanfigarieshan: anuon vairos skiana: ''$1''",
'virus-scanfailed' => 'skian fiel (kuod $1)',
'virus-unknownscanner' => 'anuon antivairos:',

# Login and logout pages
'logouttext' => "'''Yu nou lag out.'''

Yu kiahn kantiniu yuuz {{SITENAME}} ananimosli, ar yu kiahn <span class='plainlinks'>[$1 lag iin agen]</span> az di siem ar az difrant yuuza.
Nuot se som piej maita kantiniu fi displie laik se yu stil log iin, antel yu klier yu brouza kiash.",
'yourname' => 'Yuuzaniem:',
'yourpassword' => 'Paaswod:',
'yourpasswordagain' => 'Ritaip paaswod:',
'remembermypassword' => 'Memba mi lagiin pan dis brouza (fi a maximom a $1 {{PLURAL:$1|die|die}})',
'yourdomainname' => 'Yu domien:',
'externaldberror' => 'Aida aatentikieshan dietabies era okor ar yu no lou fi opdiet yu extoernal akount.',
'login' => 'Lag iin',
'nav-login-createaccount' => 'Lag iin / kriet akount',
'loginprompt' => 'Yu mos ab kukidem eniebl fi lag iin tu {{SITENAME}}.',
'userlogin' => 'Lag iin / kriet akount',
'userloginnocreate' => 'Lag iin',
'logout' => 'Lag out',
'userlogout' => 'Lag out',
'notloggedin' => 'No lag iin',
'nologin' => 'Naa no akount? $1.',
'nologinlink' => 'Kriet a akount',
'createaccount' => 'Kriet akount',
'gotaccount' => 'Aredi gat akount? $1.',
'gotaccountlink' => 'Lag iin',
'userlogin-resetlink' => 'Figet yu lagin detail dem?',
'createaccountmail' => 'Bai e-miel',
'createaccountreason' => 'Riizn:',
'badretype' => 'Di paaswod yu enta no mach.',
'userexists' => 'Yuuza niem enta aredi a yuuz.
Begyu chuuz wahn difrahn niem.',
'loginerror' => 'Lagiin era',
'createaccounterror' => 'Kudn kriet akount: $1',
'nocookiesnew' => 'Di yuuza akount kriet, bot yu no lag iin.
{{SITENAME}} yuuz kuki fi lag iin yuuza.
Yu gat kukidem disiebl.
Begyu eniebl dem, den lag iin wid yu nyuu yuuzaniem ahn paaswod.',
'nocookieslogin' => '{{SITENAME}} yuuz kuki fi lag iin yuuza.
Yu gat kukidem disiebl.
Begyu eniebl dem ahn chrai agen.',
'noname' => 'Yu no spesifai no valid yuuza niem.',
'loginsuccesstitle' => 'Lagiin soksesful',
'loginsuccess' => "'''Yu nou lag iin tu {{SITENAME}} az \"\$1\".'''",
'nosuchuser' => 'No yuuza no de bai di niem "$1".
Yuuza niem kies sensitiv.
Chek yu spelin, ar [[Special:UserLogin/signup|kriet a nyuu akount]].',
'nosuchusershort' => 'No yuuza no de bai di niem "$1".
Chek yu spelin.',
'nouserspecified' => 'Yu afi spesifai a yuuzaniem.',
'login-userblocked' => 'Dis yuuza blak. No lagiin no lou.',
'wrongpassword' => 'Inkarek paaswod enta.
Begyu chrai agen.',
'wrongpasswordempty' => 'Paaswod enta ehn blangk.
Begyu chrai agen.',
'passwordtooshort' => 'Paaswod mos bi at liis {{PLURAL:$1|1 kiarakta|$1 kiarakta}}.',
'password-name-match' => 'Yu paaswod mos difrahn frahn yu yuuzaniem.',
'mailmypassword' => 'E-miel nyuu paaswod',
'passwordremindertitle' => 'Nyuu tempareri paaswod fi {{SITENAME}}',
'passwordremindertext' => 'Smadi (prabli yu, frahn IP ajres $1) rikwest a nyuu
paaswod fi {{SITENAME}} ($4). A tempareri paaswod fi yuuza
"$2" wehn kriet ahn set to "$3". Ef dis wehna yu
intent, yu wi niid fi lag iin ahn chuuz a nyuu paaswod nou.
Yu tempareri paaswod wi expaya ina {{PLURAL:$5|wan die|$5 die}}.

Ef smadi els ehn mek dis rikwes, ar ef yu sens memba yu paaswod,
ahn yu no langa wish fi chienji, yu kiahn ignuor dis mechiz ahn
kantiniu yuuz yu uol paaswod.',
'noemail' => 'No e-miel ajres no rekaad fi yuuza "$1".',
'noemailcreate' => 'Yu niid fi provaid a valid e-miel ajres.',
'passwordsent' => 'A nyuu paaswod sen gaan tu di e-miel ajres rejista fi "$1".
Begyu lag iin agen afta yu risiibi.',
'blocked-mailpassword' => 'Yu IP ajres blak frahn editin, ahn so ino lou fi yuuz di paaswod rikovri fongshan fi privent abyuus.',
'eauthentsent' => 'Kanfamieshan e-miel sen tu di naminietid e-miel ajres.
Bifuo eni ada e-miel sen tu di akount, yu wi afi fala di inschrokshan ina di e-miel, fi kanfoerm se di akount a akchuali fiyu.',
'throttled-mailpassword' => 'Paaswod rimainda sen aredi, widin di laas {{PLURAL:$1|howa|$1 howa}}.
Fi privent abyuus, onggl wan paaswod rimainda wi sen poer {{PLURAL:$1|howa|$1 howa}}.',
'mailerror' => 'Era a sen miel: $1',
'acct_creation_throttle_hit' => 'Vizita tu dis wiki uu a yuuz yu IP ajres don kriet {{PLURAL:$1|1 akount|$1 akount}} ina di laas die, ush a di maximom lou ina dis taim piiriad.
Az a rizolt, vizita a yuuz dis IP ajres kyaahn kriet no muo akount a di muoment.',
'emailauthenticated' => 'Yu e-miel ajres aatentikiet pahn $2 a $3.',
'emailnotauthenticated' => 'Yu e-miel ajres no aatentikiet yet.
No e-miel naa sen fi eni a di falarin fiicha.',
'noemailprefs' => 'Spesifai a e-miel ajres ina yu prefransdem fi demaya fiicha fi wok.',
'emailconfirmlink' => 'Kanfoerm yu e-miel ajres.',
'invalidemailaddress' => 'Di e-miel ajres no aksep az iapier fi ab invalid faamat.
Begyu enta a wel-faamat ajres ar emti dat fiil.',
'accountcreated' => 'Akount kriet.',
'accountcreatedtext' => 'Di yuuza akount fi $1 don kriet.',
'createaccount-title' => 'Akount krieshan fi {{SITENAME}}',
'createaccount-text' => 'Smadi kriet a akount fi yu e-miel ajres pahn {{SITENAME}} ($4) niem "$2", wid paaswod "$3".
Yu shuda lag iin ahn chienj yu paaswod nou.

Yu kiahn ignuor dis mechiz, ef dis akount kriet bai mistiek.',
'usernamehasherror' => 'Yuuzaniem kyaahn kantien no ash kiarakta.',
'login-throttled' => 'Yu mek tomoch riisant lagiin atemp.
Begyu wiet likl bifuo yu chrai agen.',
'loginlanguagelabel' => 'Langwij: $1',
'suspicious-userlogout' => 'Yu rikwes fi lag out dinai bikaa iluk laik se isen bai a brok brouza ar kiashin praxi.',

# Change password dialog
'resetpass' => 'Chienj paaswod',
'resetpass_announce' => 'Yu lag iin wid a tempareri e-miel kuod.
Fi finish lag iin, yu mos set a nyuu paaswod yaso:',
'resetpass_header' => 'Chienj akount paaswod',
'oldpassword' => 'Uol paaswod:',
'newpassword' => 'Nyuu paaswod:',
'retypenew' => 'Ritaip nyuu paaswod:',
'resetpass_submit' => 'Set paaswod ahn lag iin',
'changepassword-success' => 'Yu paaswod chienj soksesfuli!
A lag yu iin nou ...',
'resetpass_forbidden' => 'Paaswod kyaahn chienj',
'resetpass-no-info' => 'Yu mos lag iin fi akses dis piej dairek.',
'resetpass-submit-loggedin' => 'Chienj paaswod',
'resetpass-submit-cancel' => 'Kiansl',
'resetpass-wrong-oldpass' => 'Invalid ar tempareri paaswod.
Yu maita chienj yu paaswod soksesfuli aredi ar rikwes wahn nyuu tempareri paaswod.',
'resetpass-temp-password' => 'Tempareri paaswod',

# Special:PasswordReset
'passwordreset-username' => 'Yuuzaniem:',
'passwordreset-domain' => 'Domien:',

# Edit page toolbar
'bold_sample' => 'Buol tex',
'bold_tip' => 'Buol tex',
'italic_sample' => 'Aitalik tex',
'italic_tip' => 'Aitalik tex',
'link_sample' => 'Lingk taikl',
'link_tip' => 'Intoernal lingk',
'extlink_sample' => 'http://www.example.com lingk taikl',
'extlink_tip' => 'Extoernal lingk (memba http:// priifix)',
'headline_sample' => 'Edlain tex',
'headline_tip' => 'Lebl 2 edlain',
'nowiki_sample' => 'Insoert nan-faamatid tex yaso',
'nowiki_tip' => 'Ignuor wiki faamatin',
'image_tip' => 'Embedid fail',
'media_tip' => 'Fail lingk',
'sig_tip' => 'Yu signicha wid taimtamp',
'hr_tip' => 'Arizantal lain (yuuz spierinli)',

# Edit pages
'summary' => 'Somari:',
'subject' => 'Sobjik/edlain',
'minoredit' => 'Dis a maina edit',
'watchthis' => 'Wach dis piej',
'savearticle' => 'Sieb piej',
'preview' => 'Priivyuu',
'showpreview' => 'Shuo priivyuu',
'showlivepreview' => 'Laiv priivyuu',
'showdiff' => 'Shuo chienjdem',
'anoneditwarning' => "'''Waanin:''' Yu no lag iin.
Yu IP ajres wi rikaad ina dis piej edit ischri.",
'anonpreviewwarning' => "''Yu no lag iin. Sievin wi rikaad yu IP ajres ina dis piej edit ischri.''",
'missingsummary' => "'''Rimainda:''' Yu no provaid no edit somari.
Ef yu klik \"{{int:savearticle}}\" agen, yu edit wi siev widoutn wan.",
'missingcommenttext' => 'Begyu enta a kament biluo.',
'missingcommentheader' => "'''Rimainda:''' Yu no provaid no sobjek/edlain fi dis kament.
Ef yu klik \"{{int:savearticle}}\" agen, yu edit wi siev widoutn wan.",
'summary-preview' => 'Somari priivyuu',
'subject-preview' => 'Sobjek/edlain priivyuu:',
'blockedtitle' => 'Yuuza blak',
'blockedtext' => "'''Yu yuuza niem ar IP ajres get blak.'''

Di blak mek bai $1.
Di riizn dehn gi a ''$2''.

* Taat a blak: $8
* Expairi a blak: $6
* Intendid blakii: $7

Yu kiahn kantak $1 ar aneda [[{{MediaWiki:Grouppage-sysop}}|adminischrieta]] fi diskos di blak.
Yu kyaahn yuuz di 'e-miel dis yuuza' fiicha anles a valid e-miel ajress spesifai ina yu [[Special:Preferences|akount prefransdem]] ahn yu no  blak frahn yuuzi.
Yu korant IP ajress a $3, ahn di blak ID a #$5.
Begyu inkluud aal abov ditiel ina eni kwieri yu mek.",
'autoblockedtext' => 'Yu IP ajres aatamatikali blak bikaa iyuuz bai aneda yuuza, uu get blak bai $1.
Di riizn dehn gi a dis:

:\'\'$2\'\'

* Taat a blak: $8
* Expairi a blak: $6
* Intendid blakii: $7

Yu kiahn kantak $1 ar wan a dieda [[{{MediaWiki:Grouppage-sysop}}|adminischrieta]] fi diskos di blak.

Nuot se yu kyaahn yuuz di "e-miel dis yuuza" fiicha anles yu gat a valid e-miel ajress rejista ina yu [[Special:Preferences|yuuza prefransdem]] ahn yu no  blak frahn yuuzi.

Yu korant IP ajress a $3, ahn di blak ID a #$5.
Begyu inkluud aal abov ditiel ina eni kwieri yu mek.',
'blockednoreason' => 'no riizn no gi',
'whitelistedittext' => 'Yu afi $1 fi edit piej',
'confirmedittext' => 'Yu mos kanfoerm yu e-miel ajres bifuo yu edit piej.
Begyu set ahn validiet yu e-miel ajres chruu yu [[Special:Preferences|yuuza prefransdem]].',
'nosuchsectiontitle' => 'Kyaahn fain sekshan',
'nosuchsectiontext' => 'Yu chrai fi edit sekshan wa no egzis.
Imaita muuv ar diliit wails yu a vyuu di piej.',
'loginreqtitle' => 'Lagiin rikwaya',
'loginreqlink' => 'Lag iin',
'loginreqpagetext' => 'Yu mos $1 fi vyuu ada piej',
'accmailtitle' => 'Paaswod sen.',
'accmailtext' => "A random jinariet paaswod fi [[User talk:$1|$1]] sen tu $2.

Di paaswod fi dis nyuu akount kiahn chienj a di ''[[Special:ChangePassword|chienj paaswod]]'' piej afta yu lag iin.",
'newarticle' => '(Nyuu)',
'newarticletext' => "Yu fala lingk tu piej we no egzis yet.
Fi kriet di piej, taat taip ina di bax biluo (si di [[{{MediaWiki:Helppage}}|elp piej]] fi muo infamieshan).
Ef yu de ya by mistiek, klik yu brouza '''bak''' botn.",
'anontalkpagetext' => "----''Dis a di diskoshan piej fi ananimos yuuza uu no kriet no akount yet, ar uu no yuuzi.
Wi dierfuor afi yuuz di nyuumerikal IP ajres fi aidentifai im/ar.
Soch a IP ajres kiahn shier bai sebral yuuza.
Ef yu a ananimos yuuza ahn fiil se irelivant kament dairek tu yu, begyu [[Special:UserLogin/signup|kriet a akount]] ar [[Special:UserLogin|lag iin]] fi avaid fyuucha kanfyuujan wid ada ananimos yuuza.''",
'noarticletext' => 'Korentli no tex no de ina dis piej.
Yu kiahn [[Special:Search/{{PAGENAME}}|saach fi dis piej taikl]] ina ada piej,
<span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} saach di rilietid lagdem],
ar [{{fullurl:{{FULLPAGENAME}}|action=edit}} edit dis piej]</span>.',
'userpage-userdoesnotexist' => 'Yuuza akount "<nowiki>$1</nowiki>" no rejista.
Begyu chek ef yu waahn fi kriet/edit dis piej.',
'userpage-userdoesnotexist-view' => 'Yuuza akount "$1" no rejista.',
'blocked-notice-logextract' => 'Dis yuuza korantli blak.
Di lietis blak lag enchri provaid biluo fi refrans:',
'usercssyoucanpreview' => "'''Tip:''' Yuuz di \"{{int:showpreview}}\" botn fi tes yu nyuu CSS bifuo yu sieb.",
'userjsyoucanpreview' => "'''Tip:''' Yuuz di \"{{int:showpreview}}\" botn fi tes yu nyuu JavaScript bifuo yu sieb.",
'usercsspreview' => "'''Memba se yu onggl a priivyuu yu yuuza CSS.'''
'''Ino sieb yet!'''",
'userjspreview' => "'''Memba se yu onggl a tes/priivyuu yu yuuza JavaScript.'''
'''Ino sieb yet!'''",
'userinvalidcssjstitle' => "'''Waanin:''' No skin \"\$1\" no de.
Memba se kostom .css ahn .js piej yuuz a luwakies taikl, e.g. {{ns:user}}:Foo/vector.css az opuoz tu {{ns:user}}:Foo/Vector.css.",
'updated' => '(Opdiet)',
'note' => "'''Nuot:'''",
'previewnote' => "'''Memb se dis a onggl priivyuu.'''
Yu chienjdem no sieb yet!",
'previewconflict' => 'Dis priivyuu riflek di tex ina di opa editin ieria az iwi apier ef yu chuuz fi siebi.',
'session_fail_preview' => "'''Sari! Wi kudn pruoses yu edit juu tu a laas a seshan dieta.'''
Begyu chrai agen.
Ef istil no wok, chrai [[Special:UserLogout|lag out]] ahn lag bak iin.",
'session_fail_preview_html' => "'''Sari! Wi kudn pruoses yu edit juu tu laas a seshan dieta.'''

''Bikaa {{SITENAME}} ab raa HTML eniebl, di priivyuu aidwe az prikaashan gens JavaScript atak.''

'''Ef dis a lejitimet edit atemp, begyu chrai agen.'''
Ef istil no wok, chrai [[Special:UserLogout|lag out]] ahn lag bak iin.",
'token_suffix_mismatch' => "'''Yu edit rijek bikaa yu klayant manggl di pongtyueshan kiaraktadem ina di edit tuokn.'''
Di edit rijek fi privent koropshan a di piej tex.
Dis somtaim apn wen yu a yuuz a bogi web-bies ananimos praxi saabis.",
'editing' => 'Editin $1',
'editingsection' => 'Editin $1 (sekshan)',
'editingcomment' => 'Editin $1 (nyuu sekshan)',
'editconflict' => 'Edit kanflik: $1',
'explainconflict' => "Smadi els chienj dis poej sens yu taat editi.
Di opa tex ieria kantien di piej tex az ikorantli egzis.
Yu chienjdem shuo ina di lowa tex ieria.
Yu wi afi moerj yu chienjdem ina di egzisin tex.
'''Onggl''' di tex ina di opa tes ieria wi sieb wen yu pres \"{{int:savearticle}}\".",
'yourtext' => 'Yu tex',
'storedversion' => 'Stuor rivijan',
'yourdiff' => 'Difrans',
'copyrightwarning' => "Begyu nuot se aal kanchribyuushan tu {{SITENAME}} rigyaad az riliis anda di $2 (si $1 fi ditiel).
Ef yu no waant yu raitn fi bi edit kyaahn don ahn ridischribyuut aal bout, den no sobmiti yaso.<br />
Yu de pramis wi alzwel se a yu rait dis yuself, ar kapi'i frahn a poblik domien ar simila frii rizuos.
'''No sobmit kapiraitid wok widoutn poermishan!'''",
'templatesused' => '{{PLURAL:$1|Templit|Templitdem}} yuuz pahn dis piej:',
'templatesusedpreview' => '{{PLURAL:$1|Templit|Templitdem}} yuuz ina dis priivyuu:',
'template-protected' => '(protek)',
'template-semiprotected' => '(semi-protek)',
'hiddencategories' => 'Dis piej a memb a {{PLURAL:$1|1 idn kiatigari|$1 idn kiatigari}}:',
'permissionserrors' => 'Permishan herro',
'permissionserrorstext-withaction' => 'Yu no ab no poermishan fi $2, fi di falarin {{PLURAL:$1|riizn|riizndem}}:',
'edit-conflict' => 'Hedit kanflik: $1',

# Account creation failure
'cantcreateaccounttitle' => 'Cyannat mek di hakkount',

# History pages
'viewpagelogs' => 'Vyuu lagdem fi dis piej',
'currentrev-asof' => 'Lietis rivijan az av $1',
'revisionasof' => 'Rivijan az av $1',
'previousrevision' => '← Uola rivijan',
'nextrevision' => 'Nyuwa rivijan',
'currentrevisionlink' => 'Lietis rivijan',
'cur' => 'kor',
'next' => 'nexx',
'last' => 'priiv',
'histlegend' => "Dif silekshan: maak di riedio bax fi di rivijandem fi kompier ahn lik enta ar di botn a di batom.<br />
Lejen: '''({{int:cur}})''' = difrans wid lietis rivijan, '''({{int:last}})''' = difrans wid prisiidn rivijan, '''{{int:minoreditletter}}''' = maina edit.",
'history-fieldset-title' => 'Brouz ischri',
'histfirst' => "Oerli'is",
'histlast' => 'Lietis',

# Revision deletion
'rev-delundel' => 'shuo/aid',
'revdel-restore' => 'chienj vizibiliti',

# Merge log
'revertmerge' => 'Anmoerj',

# Diffs
'history-title' => 'Rivijan ischri a "$1"',
'lineno' => 'Lain $1:',
'compareselectedversions' => 'Kompier silektid rivijan',
'editundo' => 'andu',

# Search results
'searchresults' => 'Saach rizolt',
'searchresults-title' => 'Saach rizolt fi "$1"',
'searchresulttext' => 'Fi muo infamieshan bout saachin {{SITENAME}}, si [[{{MediaWiki:Helppage}}|{{int:help}}]].',
'searchsubtitle' => 'Yu saach fi \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|aal piej taat wid "$1"]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|aal piej wa lingk tu "$1"]])',
'searchsubtitleinvalid' => "Yu saach fi '''$1'''",
'notitlematches' => 'No piej taikl mach',
'notextmatches' => 'No piej tex mach',
'prevn' => 'priivos {{PLURAL:$1|$1}}',
'nextn' => 'nex {{PLURAL:$1|$1}}',
'viewprevnext' => 'Vyuu ($1 {{int:pipe-separator}} $2) ($3)',
'search-result-size' => '$1 ({{PLURAL:$2|1 wod|$2 wod}})',
'search-redirect' => '(riidirek $1)',
'search-section' => '(sekshan $1)',
'search-suggest' => 'Yu wehn miin: $1',
'search-interwiki-caption' => 'Sista prajek',
'search-interwiki-default' => '$1 rizoltdem:',
'search-interwiki-more' => '(muo)',
'nonefound' => "'''Nuot''': Onggl som niemspies saach bai difaalt.
Chrai priifix yu kwieri wid ''all:'' fi saach aal kantent (inkluudn taak piej, templit, esechra), ar yuuz di dizaya niemspies fi priifix.",
'powersearch' => 'Advans saach',
'powersearch-legend' => 'Advans saach',
'powersearch-ns' => 'Saach ina niemspies:',
'powersearch-redir' => 'Lis riidirek',
'powersearch-field' => 'Saach fi',

# Preferences page
'preferences' => 'Prefrens',
'mypreferences' => 'Mi prefrans',

# Groups
'group-sysop' => 'Adminischrieta',

'grouppage-sysop' => '{{ns:project}}:Adminischrieta',

# Special:Log/newusers
'newuserlogpage' => 'Yuuza krieshan lag',

# User rights log
'rightslog' => 'Yuuza raits lag',

# Associated actions - in the sentence "You do not have permission to X"
'action-edit' => 'edit dis piej',

# Recent changes
'nchanges' => '$1 {{PLURAL:$1|chienj|chienjdem}}',
'recentchanges' => 'Riisant chienjdem',
'recentchanges-legend' => 'Riisant chienj apshan',
'recentchanges-feed-description' => 'Chrak di muos riisant chienjdem tu di wiki ina dis fiid.',
'rcnote' => "Below {{PLURAL:$1|a '''1''' chienj|a di laas '''$1''' chienj}} ina di laas {{PLURAL:$2|die|'''$2''' die}}, az av $5, $4.",
'rclistfrom' => 'Shuo nyuu chienjdem we taat frahn $1',
'rcshowhideminor' => '$1 maina editdem',
'rcshowhidebots' => '$1 batdem',
'rcshowhideliu' => '$1 lag-iin yuuzadem',
'rcshowhideanons' => '$1 ananimos yuuzadem',
'rcshowhidemine' => '$1 mi editdem',
'rclinks' => 'Shuo laas $1 chienj ina laas $2 die<br />$3',
'diff' => 'dif',
'hist' => 'isch',
'hide' => 'Aid',
'show' => 'Shuo',
'minoreditletter' => 'm',
'newpageletter' => 'N',
'boteditletter' => 'b',
'rc-enhanced-expand' => 'Shuo ditiel (rikwaya JavaScript)',
'rc-enhanced-hide' => 'Aid ditiel',

# Recent changes linked
'recentchangeslinked' => 'Rilietid chienj',
'recentchangeslinked-title' => 'Chienj riliet tu "$1"',
'recentchangeslinked-summary' => "Dis a lis a riisent chienj wa mek tu piej wa lingk frahn spesifai piej (ar tu memba a spesifai kiatigeri).
Piej pahn [[Special:Watchlist|yu wachlis]] dem '''buol'''.",
'recentchangeslinked-page' => 'Piej niem',
'recentchangeslinked-to' => 'Shuo chienjdem tu piej wa lingk tu di gibn piej insted',

# Upload
'upload' => 'Opluod fail',
'uploadlogpage' => 'Opluod lag',
'uploadedimage' => 'opluodid "[[$1]]"',

# File description page
'filehist' => 'Fail ischri',
'filehist-help' => 'Klik pan a diet/taim fi vyuu di fail az ou iapier a di taim.',
'filehist-current' => 'korant',
'filehist-datetime' => 'Diet/Taim',
'filehist-thumb' => 'Tomniel',
'filehist-thumbtext' => 'Tomniel fi voerjan az av $1',
'filehist-user' => 'Yuuza',
'filehist-dimensions' => 'Daimenshan',
'filehist-comment' => 'Kament',
'imagelinks' => 'Fail lingk',
'linkstoimage' => 'Di falarin {{PLURAL:$1|piej lingk|$1 piejdem lingk}}',
'sharedupload' => 'Dis fail kom frahn $1 ahn kiahn yuuz bai ada prajek.',
'uploadnewversion-linktext' => 'Opluod nyuu voerjan a dis fail',

# Statistics
'statistics' => 'Tatistik',

# Miscellaneous special pages
'nbytes' => '$1 {{PLURAL:$1|bait|bait}}',
'nmembers' => '$1 {{PLURAL:$1|memba|membadem}}',
'prefixindex' => 'Aal piej wid priifix',
'newpages' => 'Nyuu piejdem',
'move' => 'Muuv',
'movethispage' => 'Muuv dis piej',
'pager-newer-n' => '{{PLURAL:$1|nyuwa 1|nyuwa $1}}',
'pager-older-n' => '{{PLURAL:$1|uola 1|uola $1}}',

# Book sources
'booksources' => 'Buk suos',
'booksources-search-legend' => 'Saach fi buk suos',
'booksources-go' => 'Gwaan',

# Special:Log
'log' => 'Lagdem',

# Special:AllPages
'allpages' => 'Aal piej',
'alphaindexline' => '$1 tu $2',
'prevpage' => 'Priivos piej ($1)',
'allpagesfrom' => 'Displie piej taat a:',
'allpagesto' => 'Displie piej en a:',
'allarticles' => 'Aal piej',
'allpagessubmit' => 'Gwaan',

# Special:LinkSearch
'linksearch' => 'Extoernal lingk',

# Special:ListGroupRights
'listgrouprights-members' => '(lis a memba)',

# Email user
'emailuser' => 'E-miel dis yuuza',

# Watchlist
'watchlist' => 'Mi wachlis',
'mywatchlist' => 'Mi wachlis',
'addedwatchtext' => "Di piej \"[[:\$1]]\" don ad tu yu [[Special:Watchlist|wachlis]].
Fyuucha chienj tu dis piej ahn iasuosietid taak piej wi lis de, ahn di piej wi apier '''buoldid''' ina di [[Special:RecentChanges|lis a riisent chienjdem]] fi meki iizia fi pik out.",
'removedwatchtext' => 'Di piej "[[:$1]]" rimuuv gaan frahn [[Special:Watchlist|yu wachlis]].',
'watch' => 'Wach',
'watchthispage' => 'Wach dis piej',
'unwatch' => 'Anwach',
'watchlist-details' => '{{PLURAL:$1|$1 piej|$1 piej}} pahn yu wachlis, naa kount taak piej.',
'wlshowlast' => 'Shuo laas $1 howa $2 die $3',
'watchlist-options' => 'Wachlis apshan',

# Displayed when you click the "watch" button and it is in the process of watching
'watching' => 'De wach ...',
'unwatching' => 'De anwach ...',

# Delete
'deletepage' => 'Diliit piej',
'confirmdeletetext' => "Yu bout fi diliit a piej alangx wid aal a i'ischri.
Begyu kanfoerm se yu inten fi du dis, se yu andastan di kansikwens, ahn se yu a du dis askaadans wid [[{{MediaWiki:Policy-url}}|di palisi]].",
'actioncomplete' => 'Akshan kompliit',
'deletedtext' => '"$1" don diliit.
Si $2 fi a rekaad a riisant diliishan.',
'dellogpage' => 'Diliishan lag',
'deletecomment' => 'Riizn:',
'deleteotherreason' => 'Ada/adishanal riizn:',
'deletereasonotherlist' => 'Ada riizn',

# Rollback
'rollbacklink' => 'ruolbak',

# Protect
'protectlogpage' => 'Protekshan lag',
'protectedarticle' => 'don protek "[[$1]]"',
'modifiedarticleprotection' => 'don chienj protekshan lebl fi "[[$1]]"',
'protectcomment' => 'Riizn:',
'protectexpiry' => 'Expaya:',
'protect_expiry_invalid' => 'Expairi taim invalid.',
'protect_expiry_old' => 'Expairi taim ina di paas.',
'protect-text' => "Yu kiahn vyuu ahn chienj di protekshan lebl yaso fi di piej '''$1'''.",
'protect-locked-access' => "Yu akount no ab no poermishan fi chienj piej protekshan lebl.
Demaya a di korant setndem fi di piej '''$1''':",
'protect-cascadeon' => "Dis piej korantli protek kaa i'inkluud ina di falarin {{PLURAL:$1|piej, ush ab|piejdem, ush ab}} kiaskiedn protekshan ton aan.
Yu kiahn chienj dis piej protekshan lebl, bot inaa go afek di kiaskiedn protekshan.",
'protect-default' => 'Lou aal yuuza',
'protect-fallback' => 'Rikwaya "$1" poermishan',
'protect-level-autoconfirmed' => 'Blak nyuu ahn anrejista yuuza',
'protect-level-sysop' => 'Adminischrieta onli',
'protect-summary-cascade' => 'kiaskiedn',
'protect-expiring' => 'expaya $1 (UTC)',
'protect-cascade' => 'Protek piej wa inkluud ina dis piej (kiaskiedn protekshan)',
'protect-cantedit' => 'Yu kyaahn chienj no protekshan lebl a dis piej, kaa yu no ab no poermishan fi editi.',
'restriction-type' => 'Poermishan:',
'restriction-level' => 'Rischrikshan lebl:',

# Undelete
'undeletelink' => 'vyuu/ristuor',

# Namespace form on various pages
'namespace' => 'Niemspies',
'invert' => 'Invoert silekshan',
'blanknamespace' => '(Mien)',

# Contributions
'contributions' => 'Yuuza kanchribyuushan',
'contributions-title' => 'Yuuza kanchribiushan fi $1',
'mycontris' => 'Mi kanchribyuushan',
'contribsub2' => 'Fi $1 ($2)',
'uctop' => '(tap)',
'month' => 'Frahn mont (ahn oerlia):',
'year' => 'Frahn ier (ahn oerlia):',

'sp-contributions-newbies' => 'Shuo kanchribiushan fi onggl nyuu akount',
'sp-contributions-blocklog' => 'Blak lag',
'sp-contributions-search' => 'Saach fi kanchribiushan',
'sp-contributions-username' => 'IP ajres ar yuuzaniem',
'sp-contributions-submit' => 'Saach',

# What links here
'whatlinkshere' => 'Wa lingk ya',
'whatlinkshere-title' => 'Piej wa lingk tu "$1"',
'whatlinkshere-page' => 'Piej:',
'linkshere' => "Di falarin piejdem lingk tu '''[[:$1]]''':",
'isredirect' => 'riidirek piej',
'istemplate' => 'chranskluujan',
'isimage' => 'imij lingk',
'whatlinkshere-prev' => '{{PLURAL:$1|priivos|priivos $1}}',
'whatlinkshere-next' => '{{PLURAL:$1|nex|nex $1}}',
'whatlinkshere-links' => '← lingkdem',
'whatlinkshere-hideredirs' => '$1 riidirek',
'whatlinkshere-hidetrans' => '$1 chransklujan',
'whatlinkshere-hidelinks' => '$1 lingkdem',
'whatlinkshere-filters' => 'Filta',

# Block/unblock
'blockip' => 'Blak yuuza',
'ipboptions' => '2 owa:2 hours,1 die:1 day,3 die:3 days,1 wiik:1 week,2 wiik:2 weeks,1 mont:1 month,3 mont:3 months,6 mont:6 months,1 ier:1 year,infinet:infinite',
'ipblocklist' => 'IP ajres and yuuzaniem dem wa blak',
'blocklink' => 'blak',
'unblocklink' => 'anblak',
'change-blocklink' => 'chienj blak',
'contribslink' => 'kanchribdem',
'blocklogpage' => 'Blak lag',
'blocklogentry' => 'blak [[$1]] wid expairi taim a $2 $3',
'unblocklogentry' => 'anblak $1',
'block-log-flags-nocreate' => 'akount krieshan disiebl',

# Move page
'movepagetext' => "Yuuz di faam biluo fi riniem a piej, ahn muuv aal a i'ischri tu di nyuu niem.
Di uol taikl wi bikomz a riidirek piej tu di nyuu taikl.
Yu kiahn opdiet riidirek wa paint tu di orijinal taikl aatamatikali.
Ef yu no chuuz fi dwiit, bi shuor fi chek fi [[Special:DoubleRedirects|dobl]] ar [[Special:BrokenRedirects|brok riidirek]].
Yu rispans fi mek shuor se lingk kantiniu fi paint we dehn supuoz fi go.

Nuot se di piej '''naa''' go muuv ef piej de aredi a di nyuu taikl, anles iempti ar a riidirek ahn no ha no paas edit ischri.
Dis miin se yu kiahn riiniem a piej bak tu wa iriiniem fram ef yu mek mistiek, ahn yu kyaahn uovarait a egzistin piej.

'''Waanin!'''
Dis kiahn bi a jrastik ahn anexpektid chienj fi a papiula piej;
begyu mek shuor yu andastan di kansikwens a dis bifuo yu prosiid.",
'movepagetalktext' => "Di asuosietid taak piej wi aatamatikali muuv alangx widi '''anles:'''
* A nan-emti taak piej egzis aredi anda di nyuu niem, ar
*Yu anchel di bax biluo.

Ina demde kies, yu wi afi muuv ar moerj di piej manyuali ef yu dizaya.",
'movearticle' => 'Muuv piej',
'newtitle' => 'Tu nyuu taikl:',
'move-watch' => 'Wach suos piej ahn taagit piej',
'movepagebtn' => 'Muuv piej',
'pagemovedsub' => 'Muuv soksiid',
'movepage-moved' => '\'\'\'"$1" muuv gaan a "$2"\'\'\'',
'articleexists' => 'Piej wid daade niem egzis aredi, ar di niem yu chuuz no valid.
Begyu chuuz aneda niem.',
'talkexists' => "'''Di piej iself don muuv soksesfuli, bot di taak piek kudn muuv kaazn se wan egzis aredi a di nyuu taikl.
Begyu moerj dem manyuali.'''",
'movedto' => 'muuv gaan a',
'movetalk' => 'Muuv asuosietid taak piej',
'movelogpage' => 'Muuv lag',
'movereason' => 'Riizn:',
'revertmove' => 'rivoert',

# Export
'export' => 'Expuot piejdem',

# Thumbnails
'thumbnail-more' => 'Inlaaj',

# Special:Import
'import' => 'Himpuot piejdem',
'import-comment' => 'Kament:',

# Tooltip help for the actions
'tooltip-pt-userpage' => 'Yu yuuza piej',
'tooltip-pt-mytalk' => 'Yu taak piej',
'tooltip-pt-preferences' => 'Yu prefrans',
'tooltip-pt-watchlist' => 'Di lis a piej yu a manita fi chienj',
'tooltip-pt-mycontris' => 'Lis a yu kanchribyuushan',
'tooltip-pt-login' => 'Yu inkorij fi lag iin; ousomeba, ino mos ahn boun',
'tooltip-pt-logout' => 'Lag out',
'tooltip-ca-talk' => 'Diskoshan bout di kantent piej',
'tooltip-ca-edit' => 'Yu kiahn edit dis piej. Du yuuz di priivyuu botn bifuo yu sieb',
'tooltip-ca-addsection' => 'Taat a nyuu sekshan',
'tooltip-ca-viewsource' => 'Dis piej protek.
Yu kiahn vyuu isuos.',
'tooltip-ca-history' => 'Paas rivijan a dis piej',
'tooltip-ca-protect' => 'Protek dis piej',
'tooltip-ca-delete' => 'Diliit dis piej',
'tooltip-ca-move' => 'Muuv dis piej',
'tooltip-ca-watch' => 'Ad dis piej tu yu wachlis',
'tooltip-ca-unwatch' => 'Rimuuv dis piej frahn yu wachlis',
'tooltip-search' => 'Saach {{SITENAME}}',
'tooltip-search-go' => 'Go tu a piej wid disaya egzak niem ef iegzis',
'tooltip-search-fulltext' => 'Saach di piejdem fi disaya tex',
'tooltip-n-mainpage' => 'Vizit di mien piej',
'tooltip-n-mainpage-description' => 'Vizit di mien piej',
'tooltip-n-portal' => 'Bout di prajek, wa yu kiahn du, we fi fain tingz',
'tooltip-n-currentevents' => 'Fain bakgrong infamieshan pahn korant ivent',
'tooltip-n-recentchanges' => 'Di lis a riisant chienj ina di wiki',
'tooltip-n-randompage' => 'Luod random piej',
'tooltip-n-help' => 'Di plies fi fain out',
'tooltip-t-whatlinkshere' => 'Lis a aal wiki piej wa link ya',
'tooltip-t-recentchangeslinked' => 'Riisant chienj ina piej wa lingk frahn dis piej',
'tooltip-feed-rss' => 'RSS fiid fi dis piej',
'tooltip-feed-atom' => 'Atom fiid fi dis piej',
'tooltip-t-contributions' => 'Vyuu di lis a kanchribyuushan a dis yuuza',
'tooltip-t-emailuser' => 'Sen e-miel tu dis yuuza',
'tooltip-t-upload' => 'Opluod fail',
'tooltip-t-specialpages' => 'Lis a aal peshal piej',
'tooltip-t-print' => 'Printobl voerjan a dis piej',
'tooltip-t-permalink' => 'Poermanint lingk tu dis rivijan a di piej',
'tooltip-ca-nstab-main' => 'Vyuu di kantent piej',
'tooltip-ca-nstab-user' => 'Vyuu di yuuza piej',
'tooltip-ca-nstab-special' => 'Dis a peshal piej, yu kyaahn edit di piej iself',
'tooltip-ca-nstab-project' => 'Vyuu di prajek piej',
'tooltip-ca-nstab-image' => 'Vyuu di fail piej',
'tooltip-ca-nstab-template' => 'Vyuu di templit',
'tooltip-ca-nstab-category' => 'Vyuu di kiatigari piej',
'tooltip-minoredit' => 'Maak dis az a maina edit',
'tooltip-save' => 'Siev yu chienjdem',
'tooltip-preview' => 'Priivyuu yu chienjdem, begyu yuuz dis bifuo yu sieb!',
'tooltip-diff' => 'Shuo hush chienjdem yu mek tu di tex',
'tooltip-compareselectedversions' => 'Si di difransdem bitwiin di tuu silektid rivijan a dis piej',
'tooltip-watch' => 'Ad dis piej tu yu wachlis',
'tooltip-rollback' => '"Ruolbak" rivoert edit(dem) tu dis piej a di laas kanchribiuta ina wan klik',
'tooltip-undo' => '"Andu" rivoert dis edit ahn opin di edit faam ina priivyuu muod. Ilou yu fi ad riizn ina di somari.',

# Browsing diffs
'previousdiff' => '← Uola edit',
'nextdiff' => 'Nyuwa edit',

# Media information
'file-info-size' => '$1 × $2 pixl, fail saiz: $3, MIME taip: $4',
'file-nohires' => 'No aya rezaluushan no avielobl.',
'svg-long-desc' => 'SVG fail, naminali $1 × $2 pixl, fail saiz: $3',
'show-big-image' => 'Ful rezaluushan',

# Bad image list
'bad_image_list' => 'Di faamat go so:

Onggl lis aitem (lain taat wid *) wi kansida.
Di fos lingk pan a lain mos bi a lingk tu a bad fail.
Eni sobsikwent lingk pahn di siem lain kansida fi bi eksepshan, i.e. piej we di fail maita okor inlain.',

# Metadata
'metadata' => 'Metadieta',
'metadata-help' => 'Dis fail kantien adishanal infamieshan, prabli wa ad frahn di dijital kiamara ar skiana yuuz fi kriet ar dijitaizi.
Ef di fail madifai frahn iarijinal stiet, som ditiel maita no fuli riflek di madifai fail.',
'metadata-expand' => 'Shuo extendid ditiel',
'metadata-collapse' => 'Aid extendid ditiel',
'metadata-fields' => 'EXIF metadieta fiil wa lis ina dis mechiz wi inkluud pahn imij piej displie wen di metadieta tiebl get kalaps.
Ada wandem wi aid bai difaalt.
* make
* model
* datetimeoriginal
* exposuretime
* fnumber
* isospeedratings
* focallength
* artist
* copyright
* imagedescription
* gpslatitude
* gpslongitude
* gpsaltitude',

# External editor support
'edit-externally' => 'Yuuz extoernal aplikieshan fi edit dis fail',
'edit-externally-help' => '(Si di [//www.mediawiki.org/wiki/Manual:External_editors setop inschrokshan] fi muo infamieshan)',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'aal',
'namespacesall' => 'aal',
'monthsall' => 'aal',

# Watchlist editing tools
'watchlisttools-view' => 'Vyuu rilivant chienjdem',
'watchlisttools-edit' => 'Vyuu ahn edit wachlis',
'watchlisttools-raw' => 'Edit raa wachlis',

# Special:SpecialPages
'specialpages' => 'Peshal piej',

);
